#
# spec file for package xdg-desktop-portal
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xdg-desktop-portal
Version:        0.10
Release:        lp150.1.1
Summary:        A portal frontend service for Flatpak
License:        LGPL-2.1-or-later
Group:          System/Libraries
Url:            https://github.com/flatpak/xdg-desktop-portal
# Source is _service generated, git checkout
Source:         %{name}-%{version}.tar.xz
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
Recommends:     %{name}-lang

%description
A portal frontend service for Flatpak and possibly other desktop containment frameworks.

xdg-desktop-portal works by exposing a series of D-Bus interfaces known as portals under
a well-known name (org.freedesktop.portal.Desktop) and object path (/org/freedesktop/portal/desktop).

The portal interfaces include APIs for file access, opening URIs, printing and others.

%package devel
Summary:        A portal frontend service for Flatpak -- Development files
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
A portal frontend service for Flatpak and possibly other desktop containment frameworks.

xdg-desktop-portal works by exposing a series of D-Bus interfaces known as portals under
a well-known name (org.freedesktop.portal.Desktop) and object path (/org/freedesktop/portal/desktop).

This package contains convenience files for developers.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
    --disable-pipewire
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}

%files
%license COPYING
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/interfaces
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Access.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Account.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.AppChooser.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Email.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.FileChooser.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Inhibit.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Notification.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.PermissionStore.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Print.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.RemoteDesktop.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Request.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.ScreenCast.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Screenshot.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.Session.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Account.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Device.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Documents.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Email.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.FileChooser.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Inhibit.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.NetworkMonitor.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Notification.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.OpenURI.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Print.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.ProxyResolver.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.RemoteDesktop.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Request.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.ScreenCast.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Screenshot.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Session.xml
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.PermissionStore.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Desktop.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Documents.service
%{_datadir}/doc/xdg-desktop-portal/
%{_libexecdir}/xdg-desktop-portal
%{_prefix}/lib/systemd/user/xdg-document-portal.service
%{_prefix}/lib/systemd/user/xdg-permission-store.service
%{_prefix}/lib/xdg-document-portal
%{_prefix}/lib/xdg-permission-store
%{_userunitdir}/xdg-desktop-portal.service

%files devel
%{_datadir}/pkgconfig/xdg-desktop-portal.pc

%files lang -f %{name}.lang

%changelog
* Mon Mar  5 2018 fcrozat@suse.com
- Remove BuildRequires(flatpak), it is not needed.
- Own /usr/share/dbus-1, /usr/share/dbus-1/{interfaces,services}
  which were owned by flatpak package before.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Mon Feb 26 2018 dimstar@opensuse.org
- Update to version 0.10:
  + xdg-document-portal moved here from flatpak.
  + Add a new screencast and remote desktop portal based on
    PipeWire.
- Pass --disable-pipewire to configure: pipewire has not yet been
  packaged for openSUSE.
- Add pgkconfig(fuse) BuildRequires: new dependency.
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 0.9:
  + Install pkg-config files into datadir.
  + Avoid a race in the portal APIs.
  + Change the email portal to take fds.
  + Updated translations.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 0.8:
  + Update po files.
- Changes from version 0.7:
  + notification: Fix copy+paste error.
  + notification: Subscribe to the right interface for signals.
  + If the random request ID creates a collision, pick a new random
    ID.
  + Add some rationale.
  + Fix a typo.
  + Update README.md.
  + OpenURI: Refuse to handle file: uris.
  + Add an OpenFile method.
  + OpenFile: Fix URI.
  + Cache entire flatpak info file for peer, not just app id.
  + Store the cached flatpak-info keyfile with the request.
  + OpenFile: Rewrite app paths in /usr and /app (and /newroot).
  + OpenFile: Ensure that passed O_PATH fd is correct.
  + Send more data to the appchooser.
  + Updated translations.
- Changes from version 0.6:
  + Remove what appears to be printing lines from a debugging
    session.
  + open-uri: Fix segfault crash when no content-type can be
    resolved.
  + account: Remove debug spew.
  + Update README.md.
  + Add an email portal.
  + Include the email portal in the docs.
  + build: No need to clean org.freedesktop.portal.Desktop.service
    twice.
  + Add a systemd user unit corresponding to the session service.
  + notifications: Add better debug and error messages.
  + device: Add more detail to error messages.
  + Handle g_variant_lookup failure.
  + Encode po/Makevars in UTF-8.
  + Initialize autofree string variable to NULL.
  + open-uri: Implement a more permissive policy for the OpenURI
    portal.
  + data: Fix typo in NetworkMonitor XML definition.
  + Updated translations.
* Sun Jan 22 2017 zaitor@opensuse.org
- Update to version 0.5:
  + notification: Support 'non-exported actions.
  + Fix issues found in testing.
  + Avoid a crash when removing notifications.
  + Add an Account portal.
  + Change the Account portal API.
  + Update README.md.
  + Add a version property to all portal interfaces.
  + Fix a refcounting snafu.
  + file chooser:
  - Always grant write permissions for save dialogs.
  - Fix reading the writable property.
  + Simplify version support.
  + Updated translations.
* Wed Jan 11 2017 zaitor@opensuse.org
- Update to version 0.4:
  + No longer rely on cgroups to find the app id.
  + Fix handling of mime type filters in the file chooser portal.
  + Updated translations.
* Thu Nov  3 2016 dimstar@opensuse.org
- Initial package, version 0.3.
